#!/usr/bin/env node

const libVersion = require('./package.json').version

const argv = require('yargs')
      .usage('Usage: $0 <command> [options]')
      .command('t', 'now token')
      .command('n', 'now.json name to filter your deployments')
      .help('h')
      .alias('h', 'help')
      .version(() => libVersion)
      .alias('v', 'version')
      .argv

const nowClient = require('now-client')

const now = nowClient(argv.t)

const getDeploymentsWithoutAlias = filter => Promise.all([
  now.getAliases(),
  now.getDeployments()
])
.then(([aliases, deployments]) => deployments
.filter(deploy => !aliases.find(alias => alias.deploymentId === deploy.uid) && (!filter || filter === deploy.name)))

const removeDeployments = (deployments) => {
  deployments.forEach((deployment) => {
    now.deleteDeployment(deployment.uid)
      .then(() => console.log(`${deployment.url || deployment.uid} removed ✅`))
      .catch(() => console.log(`${deployment.url || deployment.uid} ❌`))
  })
}

// you can pass your now.json name to filter your deployments
const main = () => getDeploymentsWithoutAlias(argv.n).then(deployments => removeDeployments(deployments))

module.exports = main

if (!module.parent) {
  main()
}
